@@ -105,6 +105,24 @@ class PrtgApi:
         """
         return f'{self.url}/device.htm?id={id}'
 
+    # Sensortree
+    def get_sensortree(self, group_id=None):
+        """Get sensortree
+
+        Args:
+            group_id (Union[int, str], optional): Group id of desired root. Defaults to None.
+
+        Returns:
+            str: XML structure of sensortree
+        """
+        endpoint = 'api/table.xml'
+        params = {
+            'content': 'sensortree',
+            'id': group_id
+        }
+        response = self._requests_get(endpoint, params)
+        return response.text
+
     # Probes
 
     def _get_probes_base(self, extra=None):
